@@ -1,6 +1,6 @@
 #!/usr/bin/python3
 # -*- coding: utf-8 -*-
-# Copyright 2009-2021 Univention GmbH
+# Copyright 2009-2022 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -30,4 +30,4 @@
 Python tools for Updater and repository maintenance.
 """
 
-from univention.updater.tools import UniventionUpdater  # NOQA
+from univention.updater.tools import UniventionUpdater  # noqa: F401
