@@ -1,6 +1,6 @@
 #!/usr/bin/python3
 # -*- coding: utf-8 -*-
-# Copyright 2008-2021 Univention GmbH
+# Copyright 2008-2022 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -73,8 +73,8 @@ import functools
 import six
 import base64
 try:
-    from typing import Any, AnyStr, Dict, Generator, Iterable, Iterator, List, Optional, Sequence, Set, Text, Tuple, Type, TypeVar, Union  # noqa F401
-    from typing_extensions import Literal  # noqa F401
+    from typing import Any, AnyStr, Dict, Generator, Iterable, Iterator, List, Optional, Sequence, Set, Text, Tuple, Type, TypeVar, Union  # noqa: F401
+    from typing_extensions import Literal  # noqa: F401
     _TS = TypeVar("_TS", bound="_UCSServer")
 except ImportError:
     pass
