@@ -4,7 +4,7 @@
 # Univention Management Console
 #  module: updater
 #
-# Copyright 2011-2021 Univention GmbH
+# Copyright 2011-2022 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -40,8 +40,8 @@ from hashlib import md5
 from os import stat, getpid
 from time import time
 from traceback import format_exc
-from types import ModuleType  # noqa F401
-from typing import Any, Callable, Dict, Iterable, List, Tuple, Union  # noqa F401
+from types import ModuleType  # noqa: F401
+from typing import Any, Callable, Dict, Iterable, List, Tuple, Union  # noqa: F401
 
 import notifier.threads
 from apt import Cache
